==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/acl/lang/mr/lang.php <==
<?php
/**
 * Marathi language file
 *
 * @author ghatothkach@hotmail.com
 * @author Padmanabh Kulkarni <kulkarnipadmanabh@gmail.com>
 * @author Padmanabh Kulkarni<kulkarnipadmanabh@gmail.com>
 * @author shantanoo@gmail.com
 */
$lang['admin_acl']             = 'Access Control List  व्यवस्थापन';
$lang['acl_group']             = 'गट';
$lang['acl_user']              = 'सदस्य';
$lang['acl_perms']             = 'परवानगी \'च्या साठी';
$lang['page']                  = 'पान';
$lang['namespace']             = 'नेमस्पेस';
$lang['btn_select']            = 'निवडा';
$lang['p_user_id']             = '<b class="acluser">%s</b> ह्या सदस्याला सध्या <b class="aclpage">%s</b> या पानावर पुढील परवानग्या आहेत : <i>%s</i>.';
$lang['p_user_ns']             = '<b class="acluser">%s</b> या सदस्याला सध्या <b class="aclns">%s</b> या नेमस्पेसवर पुढील परवानग्या आहेत : <i>%s</i>.';
$lang['p_group_id']            = '<b class="aclgroup">%s</b> या गटाच्या सदस्याना सध्या <b class="aclpage">%s</b> या पानावर पुढील परवानग्या आहेत : <i>%s</i>.';
$lang['p_group_ns']            = '<b class="aclgroup">%s</b> या गटाच्या सदस्याना सध्या <b class="aclns">%s</b> या नेमस्पेसवर पुढील परवानग्या आहेत : <i>%s</i>.';
$lang['p_choose_id']           = 'वरील फॉर्म मधे एखाद्या <b>सदस्य किंवा गटाचे </b> नाव टाकुन <b class="aclpage">%s</b> या पानासाठी त्यांच्या परवानग्या पाहू/बदलू शकता.';
$lang['p_choose_ns']           = 'वरील फॉर्म मधे एखाद्या <b>सदस्य किंवा गटाचे </b> नाव टाकुन <b class="aclns">%s</b> या नेमस्पेससाठी त्यांच्या परवानग्या पाहू/बदलू शकता.';
$lang['p_inherited']           = 'टीप : ह्या परवानग्या प्रत्यक्ष सेट केल्या नसून त्या इतर गट किंवा अधिक उच्च नेमस्पेस कडून वारसाहक्काने  :) आल्या आहेत.';
$lang['p_isadmin']             = 'टीप : निवडलेल्या सदस्य किंवा गटाला कायम सर्व परवानग्या असतात कारण तो सुपर सदस्य म्हणुन सेट केला आहे.';
$lang['current']               = 'सद्य ACL नियम';
$lang['where']                 = 'पान/नेमस्पेस';
$lang['who']                   = 'सदस्य/गट';
$lang['perm']                  = 'परवानग्या';
$lang['acl_perm0']             = 'काही नाही.';
$lang['acl_perm1']             = 'वाचन';
$lang['acl_perm2']             = 'संपादन';
$lang['acl_perm4']             = 'निर्माण';
$lang['acl_perm8']             = 'अपलोड';
$lang['acl_perm16']            = 'डिलीट';
$lang['acl_new']               = 'नवीन एंट्री करा';
$lang['acl_mod']               = 'एंट्री बदला';

==> dokuwiki_0.0.20120125b.orig.tar.gz: dokuwiki-2012-01-25b/lib/plugins/acl/lang/mr/lang.php <==
<?php
/**
 * Marathi language file
 *
 * @author ghatothkach@hotmail.com
 * @author Padmanabh Kulkarni <kulkarnipadmanabh@gmail.com>
 * @author Padmanabh Kulkarni<kulkarnipadmanabh@gmail.com>
 * @author shantanoo@gmail.com
 */
$lang['admin_acl']             = 'Access Control List  व्यवस्थापन';
$lang['acl_group']             = 'गट';
$lang['acl_user']              = 'सदस्य';
$lang['acl_perms']             = 'परवानगी \'च्या साठी';
$lang['page']                  = 'पान';
$lang['namespace']             = 'नेमस्पेस';
$lang['btn_select']            = 'निवडा';
$lang['p_user_id']             = '<b class="acluser">%s</b> ह्या सदस्याला सध्या <b class="aclpage">%s</b> या पानावर पुढील परवानग्या आहेत : <i>%s</i>.';
$lang['p_user_ns']             = '<b class="acluser">%s</b> या सदस्याला सध्या <b class="aclns">%s</b> या नेमस्पेसवर पुढील परवानग्या आहेत : <i>%s</i>.';
$lang['p_group_id']            = '<b class="aclgroup">%s</b> या गटाच्या सदस्याना सध्या <b class="aclpage">%s</b> या पानावर पुढील परवानग्या आहेत : <i>%s</i>.';
$lang['p_group_ns']            = '<b class="aclgroup">%s</b> या गटाच्या सदस्याना सध्या <b class="aclns">%s</b> या नेमस्पेसवर पुढील परवानग्या आहेत : <i>%s</i>.';
$lang['p_choose_id']           = 'वरील फॉर्म मधे एखाद्या <b>सदस्य किंवा गटाचे </b> नाव टाकुन <b class="aclpage">%s</b> या पानासाठी त्यांच्या परवानग्या पाहू/बदलू शकता.';
$lang['p_choose_ns']           = 'वरील फॉर्म मधे एखाद्या <b>सदस्य किंवा गटाचे </b> नाव टाकुन <b class="aclns">%s</b> या नेमस्पेससाठी त्यांच्या परवानग्या पाहू/बदलू शकता.';
$lang['p_inherited']           = 'टीप : ह्या परवानग्या प्रत्यक्ष सेट केल्या नसून त्या इतर गट किंवा अधिक उच्च नेमस्पेस कडून वारसाहक्काने  :) आल्या आहेत.';
$lang['p_isadmin']             = 'टीप : निवडलेल्या सदस्य किंवा गटाला कायम सर्व परवानग्या असतात कारण तो सुपर सदस्य म्हणुन सेट केला आहे.';
$lang['p_include']             = 'उच्च परवानग्यांमधे त्याखालिल परवानग्या अध्याहृत असतात. क्रिएट, अपलोड आणि डिलीट परवानग्या फ़क्त नामसमुहावर (नेमस्पेस) लागू असतात, पानांवर नाही.';
$lang['current']               = 'सद्य ACL नियम';
$lang['where']                 = 'पान/नेमस्पेस';
$lang['who']                   = 'सदस्य/गट';
$lang['perm']                  = 'परवानग्या';
$lang['acl_perm0']             = 'काही नाही.';
$lang['acl_perm1']             = 'वाचन';
$lang['acl_perm2']             = 'संपादन';
$lang['acl_perm4']             = 'निर्माण';
$lang['acl_perm8']             = 'अपलोड';
$lang['acl_perm16']            = 'डिलीट';
$lang['acl_new']               = 'नवीन एंट्री करा';
$lang['acl_mod']               = 'एंट्री बदला';
